# Fast Transfer

An easy and fast way to transfer files between mulitple users.
If you offten run the command `python -m http.server`, you will like it.


## Usage

```
fast-transfer /tmp
```

## Installation

```
pip install fast-transfer
```
